import { ValueFormatterParams } from '@ag-grid-community/core';
/**
 * Returns a filter type based on the Grid Pro field/column type.
 * @param type - The type of the field/column
 * @returns The ag-grid filter type
 * @remarks Currently only returns agTextColumnFilter
 * @alpha
 */
export declare function getFilterByFieldType(type: string): any;
/**
 * Return a column type base on each field's metadata from the selected resource.
 * @param metadataType - The type of the field/column
 * @returns the column type
 * @remarks Currently only handles numeric columns
 * @alpha
 */
export declare function getColumnType(metadataType: string): any;
/**
 * Returns the filter params based on the Grid Pro field/column type.
 * @param type - The type of the field/column
 * @returns the filter params for the specified field type
 * @remarks Currently only returns a default filter params object, for all field types
 * @alpha
 */
export declare function getFilterParamsByFieldType(type: string): any;
/**
 * Returns a formatted date value from the Grid Pro cell value.
 * @param param - A ValueFormatterParams object.
 * @returns A formatted date value.
 * @public
 */
export declare function dateValueFormatter({ value }: ValueFormatterParams): any;
/**
 * Returns a formatted date time value from the Grid Pro cell value.
 * @param param - A ValueFormatterParams object.
 * @returns A formatted date time value.
 * @public
 */
export declare function dateTimeValueFormatter({ value }: ValueFormatterParams): any;
/**
 * Returns a formatted date value from an epoch number.
 * @param epoch - A number representing the number of milliseconds since the Unix epoch (1 January 1970 00:00:00 UTC).
 * @returns A formatted date value.
 * @alpha
 * @deprecated No longer used in the Grid Pro package.
 */
export declare function formatDateExtra(epoch: number): string;
/**
 * The time between allowing the grids to automatically resize.
 * @internal
 */
export declare const DEBOUNCED_RESIZE_TIME = 5;
//# sourceMappingURL=grid-pro.definitions.next.d.ts.map